# == Class: docker
#
# Puppet module to install, deploy and configure docker.
#
class docker (
  $package             = true,
  $service             = true,
  $enable              = true,
  $manage_repos        = true,
  $apt_location        = $docker::params::apt_location,
  $apt_release         = $docker::params::apt_release,
  $apt_repos           = $docker::params::apt_repos,
  $apt_key             = $docker::params::apt_key,
  $docker_package_name = $docker::params::docker_package_name,
  $docker_service_name = $docker::params::docker_service_name,
  $docker_sysconfig    = $docker::params::docker_sysconfig,
  $docker_options      = $docker::params::docker_options
) inherits docker::params {
  case $package {
    true    : { $ensure_package = 'present' }
    false   : { $ensure_package = 'purged' }
    latest  : { $ensure_package = 'latest' }
    default : { fail('package must be true, false or lastest') }
  }

  case $service {
    true    : { $ensure_service = 'running' }
    false   : { $ensure_service = 'stopped' }
    default : { fail('service must be true or false') }
  }

  if ($manage_repos == true) {
    class { 'docker::repos':
      apt_location        => $apt_location,
      apt_release         => $apt_release,
      apt_repos           => $apt_repos,
      apt_key             => $apt_key,
      docker_package_name => $docker_package_name,
      docker_service_name => $docker_service_name,
    }

    package { $docker_package_name:
      ensure  => $ensure_package,
      require => Class['docker::repos'],
    }
  }
  else {
    package { $docker_package_name:
      ensure  => $ensure_package,
    }
  }

  service { $docker_service_name:
    ensure     => $ensure_service,
    enable     => $enable,
    hasrestart => true,
    hasstatus  => true,
    require    => Package[$docker_package_name],
  }

  file { $docker_sysconfig:
    ensure  => $ensure_package,
    backup  => true,
    content => template("docker/sysconfig.${::operatingsystem}.erb"),
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    require => Package[$docker_package_name],
    notify  => Service[$docker_service_name],
  }
}
# EOF
