# == Class: docker::params
#
# This is a container class holding default parameters for docker module.
#
class docker::params {
  case $::operatingsystem {
    /(?i:debian|devuan|ubuntu)/: {
      case $::lsbdistcodename {
        # Debian
        'squeeze'         : {
          $apt_location        = 'https://apt.dockerproject.org/repo'
          $apt_release         = 'debian-wheezy'
          $apt_repos           = 'main'
          $apt_key             = '58118E89F3A912897C070ADBF76221572C52609D'
          $docker_package_name = 'docker-engine'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/default/docker'
          $docker_options      = []
        }
        'wheezy'          : {
          if $::kernelmajversion < 3.16 {
            $apt_location        = 'https://apt.dockerproject.org/repo'
            $apt_release         = 'debian-wheezy'
            $apt_repos           = 'main'
            $apt_key             = '58118E89F3A912897C070ADBF76221572C52609D'
            $docker_package_name = 'docker-engine'
            $docker_service_name = 'docker'
          }
          else {
            $apt_location        = 'https://download.docker.com/linux/debian'
            $apt_release         = $::lsbdistcodename
            $apt_repos           = 'stable'
            $apt_key             = '9DC858229FC7DD38854AE2D88D81803C0EBFCD88'
            $docker_package_name = 'docker-ce'
            $docker_service_name = 'docker'
          }
          $docker_sysconfig    = '/etc/default/docker'
          $docker_options      = ''
        }
        'jessie'          : {
          $apt_location        = 'https://download.docker.com/linux/debian'
          $apt_release         = $::lsbdistcodename
          $apt_repos           = 'stable'
          $apt_key             = '9DC858229FC7DD38854AE2D88D81803C0EBFCD88'
          $docker_package_name = 'docker-ce'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/default/docker'
          $docker_options      = []
        }
        'stretch'         : {
          $apt_location        = 'https://download.docker.com/linux/debian'
          $apt_release         = $::lsbdistcodename
          $apt_repos           = 'stable'
          $apt_key             = '9DC858229FC7DD38854AE2D88D81803C0EBFCD88'
          $docker_package_name = 'docker-ce'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/default/docker'
          $docker_options      = []
        }
        /(buster|n\/a)/   : {
          $apt_location        = 'https://download.docker.com/linux/debian'
          $apt_release         = 'jessie'
          $apt_repos           = 'stable'
          $apt_key             = '9DC858229FC7DD38854AE2D88D81803C0EBFCD88'
          $docker_package_name = 'docker-ce'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/default/docker'
          $docker_options      = []
        }
        # Ubuntu
        'lucid'           : {
          $apt_location        = 'https://apt.dockerproject.org/repo'
          $apt_release         = 'ubuntu-precise'
          $apt_repos           = 'main'
          $apt_key             = '58118E89F3A912897C070ADBF76221572C52609D'
          $docker_package_name = 'docker-engine'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/default/docker'
          $docker_options      = []
        }
        'precise'         : {
          $apt_location        = 'https://apt.dockerproject.org/repo'
          $apt_release         = 'ubuntu-precise'
          $apt_repos           = 'main'
          $apt_key             = '58118E89F3A912897C070ADBF76221572C52609D'
          $docker_package_name = 'docker-engine'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/default/docker'
          $docker_options      = []
        }
        'trusty'          : {
          $apt_location        = 'https://download.docker.com/linux/ubuntu'
          $apt_release         = $::lsbdistcodename
          $apt_repos           = 'stable'
          $apt_key             = '9DC858229FC7DD38854AE2D88D81803C0EBFCD88'
          $docker_package_name = 'docker-ce'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/default/docker'
          $docker_options      = []
        }
        'xenial'          : {
          $apt_location        = 'https://download.docker.com/linux/ubuntu'
          $apt_release         = $::lsbdistcodename
          $apt_repos           = 'stable'
          $apt_key             = '9DC858229FC7DD38854AE2D88D81803C0EBFCD88'
          $docker_package_name = 'docker-ce'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/default/docker'
          $docker_options      = []
        }
        default           : {
          fail("Module ${module_name} \
          is not supported on Debian (${::lsbdistcodename})")
        }
      }
    }
    /(?i:centos|fedora|redhat)/: {
      case $::lsbmajdistrelease {
        '6'    : {
          $base                = 'https://yum.dockerproject.org'

          $location            = "${base}/repo/main/centos/6/"
          $key                 = "${base}/gpg"
          $docker_package_name = 'docker-engine'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/sysconfig/docker'
          $docker_options      = []
        }
        '7'    : {
          $base                = 'https://download.docker.com/linux/centos'

          $location            = "${base}/7/x86_64/stable"
          $key                 = "${base}/gpg"
          $docker_package_name = 'docker-ce'
          $docker_service_name = 'docker'
          $docker_sysconfig    = '/etc/sysconfig/docker'
          $docker_options      = []
        }
        default: {
          fail("Module ${module_name} \
          is not supported on CentOS ${::lsbmajdistrelease}")
        }
      }
    }
    default                    : {
      fail("Module ${module_name} \
      is not supported on ${::operatingsystem}")
    }
  }
}
# EOF
