# == Class: docker::repos
#
# This is a container class holding default parameters for docker module.
#
# https://store.docker.com/editions/community/docker-ce-server-debian
#
class docker::repos (
  $apt_location        = $docker::params::apt_location,
  $apt_release         = $docker::params::apt_release,
  $apt_repos           = $docker::params::apt_repos,
  $apt_key             = $docker::params::apt_key,
  $docker_package_name = $docker::params::docker_package_name,
  $docker_service_name = $docker::params::docker_service_name
) inherits docker::params {
  case $::operatingsystem {
    /(?i:debian|devuan|ubuntu)/: {
      if !defined(Class['apt']) {
        include apt
      }

      apt::source { 'docker':
        ensure      => present,
        location    => $apt_location,
        release     => $apt_release,
        repos       => $apt_repos,
        key         => $apt_key,
        include_src => false,
      }
    }
    /(?i:centos|fedora|redhat)/: {
      file { '/etc/yum.repos.d/docker.repo':
        ensure  => present,
        backup  => true,
        content => template('docker/docker.repo.erb'),
        owner   => 'root',
        group   => 'root',
        mode    => '0644',
      }

      exec { 'docker yum update':
        command   => 'yum update -q -y',
        path      => [ '/usr/bin', '/usr/sbin', '/bin', '/sbin' ],
        subscribe => File['/etc/yum.repos.d/docker.repo'],
      }
    }
    default                    : {
      fail("Module ${module_name} \
      is not supported on ${::operatingsystem}")
    }
  }
}
# EOF
